set character_set_client = utf8;
set character_set_connection = utf8;

create DATABASE if not exists `gbs` CHARACTER SET 'utf8mb4' COLLATE 'utf8mb4_general_ci';

use gbs;

create table if not exists t_devices
(
    `id`                 varchar(255),
    `name`               varchar(255),
    `manufacturer`       varchar(255),
    `model`              varchar(255),
    `firmware`           varchar(255),
    `remote_ip`          varchar(255),
    `remote_port`        int          default 0,
    `encoding`           varchar(255) default 'GB2312',
    `stream_mode`        tinyint      default 0,
    `transport_mode`     tinyint      default 0,
    `online`             tinyint      default 0,
    `last_register_at`   datetime,
    `last_keepalive_at`  datetime,
    `catalog_subscribe`  tinyint      default 0,
    `alarm_subscribe`    tinyint      default 0,
    `position_subscribe` tinyint      default 0,
    `updated_at`         datetime     default current_timestamp on update current_timestamp,
    `created_at`         datetime     default current_timestamp,
    primary key (`id`),
    index idx_t_devices_name (`name`),
    index idx_t_devices_manufacturer (`manufacturer`)
);

create table if not exists t_channels
(
    `id`               varchar(255),
    `device_id`        varchar(255),
    `name`             varchar(255) default '',
    `manufacturer`     varchar(255) default '',
    `model`            varchar(255) default '',
    `owner`            varchar(255) default '',
    `civil_code`       varchar(255) default '',
    `block`            varchar(255) default '',
    `address`          varchar(255) default '',
    `parental`         int          default 0,
    `parent_id`        varchar(255) default '',
    `safety_way`       int          default 0,
    `register_way`     int          default 1,
    `cert_num`         varchar(255) default '0',
    `secrecy`          int          default 0,
    `ip_address`       varchar(255) default '',
    `port`             int          default 0,
    `password`         varchar(255) default '',
    `status`           varchar(255) default 'ON',
    `longitude`        float        default 0,
    `latitude`         float        default 0,
    `info`             text,
    `snap_url`         varchar(255) default '',
    `custom`           tinyint      default 0,
    `custom_id`        varchar(255) default '',
    `custom_parent_id` varchar(255) default '',
    `updated_at`       datetime     default current_timestamp on update current_timestamp,
    `created_at`       datetime     default current_timestamp,
    primary key (`id`, `device_id`),
    index idx_t_channels_device_id (`device_id`),
    index idx_t_channels_id (`id`),
    index idx_t_channels_name (`name`),
    index idx_t_channels_manufacturer (`manufacturer`),
    index idx_t_channels_custom_id (`custom_parent_id`),
    index idx_t_channels_parent_id (`parent_id`),
    index idx_t_channels_custom (`custom`)
);

create table if not exists t_media_services
(
    `id`             varchar(255),
    `ip`             varchar(255) default '',
    `port`           int          default 0,
    `sip_id`         varchar(255),
    `sip_realm`      varchar(255),
    `sip_ip`         varchar(255) default '',
    `sip_port`       int          default 0,
    `wan_ip`         varchar(255) default '',
    `http_port`      int          default 0,
    `rtmp_port`      int          default 0,
    `rtsp_port`      int          default 0,
    `rtp_port_start` int          default 0,
    `rtp_port_end`   int          default 0,
    `desc`           varchar(255),
    `updated_at`     datetime     default current_timestamp on update current_timestamp,
    `created_at`     datetime     default current_timestamp,
    primary key (`id`)
);

create table if not exists t_storage_services
(
    `id`         varchar(255),
    `ip`         varchar(255),
    `port`       int,
    `http_port`  int      default 0,
    `desc`       varchar(255),
    `updated_at` datetime default current_timestamp on update current_timestamp,
    `created_at` datetime default current_timestamp,
    primary key (`ip`, `port`),
    unique key (`id`)
);

create table if not exists t_record_plans
(
    `id`           varchar(255),
    `name`         varchar(255),
    `enable`       tinyint  default 0,
    `ts`           text,
    `save_days`    int      default -1,
    `seg_duration` int      default 0,
    `storage_id`   varchar(255) not null,
    `updated_at`   datetime default current_timestamp on update current_timestamp,
    `created_at`   datetime default current_timestamp,
    primary key (id)
);

create table if not exists t_record_plan_channels
(
    `plan_id`    varchar(255),
    `device_id`  varchar(255),
    `channel_id` varchar(255),
    primary key (device_id, channel_id),
    index idx_t_record_plan_channels_plan_id (plan_id)
);

create table if not exists t_alarms
(
    `id`                    varchar(255) default (UUID()),
    `device_id`             varchar(255) default '',
    `device_name`           varchar(255) default '',
    `channel_id`            varchar(255) default '',
    `channel_name`          varchar(255) default '',
    `alarm_priority`        int,
    `alarm_priority_name`   varchar(255) default '',
    `alarm_method`          int,
    `alarm_method_name`     varchar(255) default '',
    `longitude`             float,
    `latitude`              float,
    `alarm_description`     varchar(255) default '',
    `info`                  text,
    `alarm_type`            int,
    `alarm_type_name`       varchar(255) default '',
    `alarm_event_type`      int,
    `alarm_event_type_name` varchar(255) default '',
    `time`                  datetime,
    `record_url`            varchar(255) default '',
    `record_path`           varchar(255) default '',
    `snap_path`             varchar(255) default '',
    `plan_description`      varchar(255) default '',
    `created_at`            datetime     default now(),
    primary key (`id`),
    index idx_t_alarms_device_id (device_id),
    index idx_t_alarms_channel_id (channel_id),
    index idx_t_alarms_time (`time`),
    index idx_t_alarms_alarm_priority (alarm_priority),
    index idx_t_alarms_alarm_method (alarm_method)
);

create table if not exists `t_cascades`
(
    `id`                 varchar(255),
    `name`               varchar(255),
    `realm`              varchar(255),
    `host`               varchar(255),
    `port`               int          default 0,
    `local_id`           varchar(255),
    `local_host`         varchar(255),
    `local_port`         int          default 0,
    `username`           varchar(255),
    `password`           varchar(255),
    `keepalive_interval` int          default 60,
    `register_interval`  int          default 3600,
    `enable`             tinyint      default 1,
    `enable_ptz`         tinyint      default 0,
    `enable_record`      tinyint      default 0,
    `transport_mode`     tinyint      default 0,
    `encoding`           varchar(255) default 'GB2312',
    `stream_reader`      int          default 0,
    `catalog_group_size` int          default 1,
    `shared_all`         tinyint      default 0,
    `online`             tinyint      default 0,
    `updated_at`         datetime     default current_timestamp on update current_timestamp,
    `created_at`         datetime     default current_timestamp,
    primary key (`id`),
    index idx_t_cascades_name (name),
    index idx_t_cascades_host (host)
);

create table if not exists `t_cascade_channels`
(
    `cascade_id` varchar(255),
    `channel_id` varchar(255),
    `device_id`  varchar(255),
    PRIMARY KEY (cascade_id, channel_id, device_id)
);

create table if not exists `t_presets`
(
    `device_id`          varchar(255),
    `channel_id`         varchar(255),
    `preset_id`          integer,
    `preset_enable`      tinyint      DEFAULT 0,
    `preset_name`        varchar(255) DEFAULT '',
    `preset_custom_name` varchar(255) DEFAULT '',
    primary key (`device_id`, `channel_id`, `preset_id`)
);

-- trigger
delimiter $$

-- drop t_cascades_channels after t_cascades deleted
drop trigger if exists t_cascades_delete $$
create trigger t_cascades_delete
    after delete
    on t_cascades
    for each row
begin
    delete from t_cascade_channels where cascade_id = OLD.id;
end $$

-- drop t_channels after t_devices deleted
drop trigger if exists t_devices_delete $$
create trigger t_devices_delete
    after delete
    on t_devices
    for each row
begin
    delete from t_channels where device_id = OLD.id;
end $$

-- drop t_record_plan_channels after t_record_plan
drop trigger if exists t_record_plan_delete $$
create trigger t_record_plan_delete
    after delete
    on t_record_plans
    for each row
begin
    delete from t_record_plan_channels where plan_id = OLD.id;
end $$

-- drop t_record_plan_channels after t_channels
drop trigger if exists t_channels_delete $$
create trigger t_channels_delete
    after delete
    on t_channels
    for each row
begin
    delete from t_record_plan_channels where device_id = OLD.device_id and channel_id = OLD.id;
    delete from t_presets where device_id = OLD.device_id and channel_id = OLD.id;
end $$

delimiter ;
